import { useLocation, useNavigate } from "react-router-dom";
import { IoMdLogOut } from "react-icons/io";
import { MdHome, MdCheckCircle } from "react-icons/md";
import { RiArrowGoBackLine } from "react-icons/ri";
import styles from "./Styles.module.css";
import Success from "../../Assets/Success.png";
import Failed from "../../Assets/Failed.png";

export const Summary = ({ success: propSuccess }) => {
  const navigate = useNavigate();
  const location = useLocation();

  const success = propSuccess ?? location.state?.success;
  const bookingInfo = location.state?.bookingInfo;

  const onLogout = () => navigate("/");

  const onBack = () => navigate("/seat-limit");

  return (
    <div className={styles.pageContainer}>
      {success === true ? (
        <div className={styles.success}>
          <div>
            <MdCheckCircle className={styles.symbol} />
          </div>
          <h1 className={styles.hd}>Booking Confirmed!</h1>
          <p className={styles.subtitle}>
            Your tickets are ready. Enjoy the show!
          </p>

          <div className={styles.qrContainer}>
            <img src={Success} alt="QR code" className={styles.qr} />
            <p className={styles.qrNote}>Your Seat, Secured in Seconds</p>
          </div>

          {bookingInfo && (
            <div className={styles.info}>
              <div className={styles.row}>
                <span className={styles.label}>Movie</span>
                <span className={styles.value}>Thug Life</span>
              </div>
              <div className={styles.row}>
                <span className={styles.label}>Seats</span>
                <div className={styles.seatWrapper}>
                  {bookingInfo.seats?.map((seat, i) => (
                    <span key={i} className={styles.seatPill}>
                      {seat}
                    </span>
                  ))}
                </div>
              </div>
              <div className={styles.row}>
                <span className={styles.label}>Seat Number</span>
                <span className={styles.value}>{bookingInfo.seats.length}</span>
              </div>
              <div className={styles.row}>
                <span className={styles.label}>Mobile Number</span>
                <span className={styles.value}>{bookingInfo.userId}</span>
              </div>
              <div className={styles.row}>
                <span className={styles.label}>Booked On</span>
                <span className={styles.value}>{bookingInfo.time}</span>
              </div>
            </div>
          )}

          <button onClick={onBack} className={styles.downloadBtn}>
            <RiArrowGoBackLine className={styles.icon} />
            <span>Book More Tickets</span>
          </button>

          <button onClick={onLogout} className={styles.homeBtn}>
            <MdHome className={styles.icon} />
            <span>Back to Home</span>
          </button>
        </div>
      ) : (
        <div className={styles.error}>
          <img src={Failed} alt="Failed" className={styles.symbol} />
          <h2 className={styles.hdError}>Something Went Wrong</h2>
          <p className={styles.timeStamp}>
            Booked On: {new Date().toLocaleString()}
          </p>
          <button onClick={onLogout} className={styles.homeBtn}>
            <IoMdLogOut className={styles.icon} />
            <span>Back to Home</span>
          </button>
        </div>
      )}
    </div>
  );
};
